# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'ScalingConfigurationEip',
    'ScalingConfigurationInstanceTypeOverride',
    'ScalingConfigurationTag',
    'ScalingConfigurationVolume',
    'ScalingGroupInstancesDistribution',
    'ScalingGroupLaunchTemplateOverride',
    'ScalingGroupServerGroupAttribute',
    'ScalingGroupTag',
    'GetScalingConfigurationEipResult',
    'GetScalingConfigurationInstanceTypeOverrideResult',
    'GetScalingConfigurationTagResult',
    'GetScalingConfigurationVolumeResult',
    'GetScalingGroupInstancesDistributionResult',
    'GetScalingGroupLaunchTemplateOverrideResult',
    'GetScalingGroupServerGroupAttributeResult',
    'GetScalingGroupTagResult',
]

@pulumi.output_type
class ScalingConfigurationEip(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "bandwidthPackageId":
            suggest = "bandwidth_package_id"
        elif key == "billingType":
            suggest = "billing_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ScalingConfigurationEip. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ScalingConfigurationEip.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ScalingConfigurationEip.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 bandwidth: Optional[builtins.int] = None,
                 bandwidth_package_id: Optional[builtins.str] = None,
                 billing_type: Optional[builtins.str] = None,
                 isp: Optional[builtins.str] = None):
        """
        :param builtins.int bandwidth: 公网IP的带宽峰值，默认为1，单位：Mbps。取值：当Eip.BillingType取值为PostPaidByBandwidth时，取值为1 ～ 500。当Eip.BillingType取值为PostPaidByTraffic时，取值为1 ～ 200。
        :param builtins.str bandwidth_package_id: 共享带宽包的ID，表示将公网IP加入到共享带宽包。 您可以调用 DescribeBandwidthPackages 接口，查询共享带宽包的ID。 公网IP加入到共享带宽包必须同时满足如下条件：二者的安全防护类型相同。二者的线路类型相同。共享带宽包为IPv4类型。
        :param builtins.str billing_type: 公网IP的计费类型，取值：PostPaidByBandwidth（默认）：按量计费-按带宽上限计费。PostPaidByTraffic：按量计费-按实际流量计费。
        :param builtins.str isp: 线路类型，取值：BGP（默认）：BGP线路。若您的账号已申请使用静态单线，ISP还可以传入ChinaMobile（表示中国移动）、ChinaTelecom（表示中国电信）、ChinaUnicom（表示中国联通）。
        """
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if bandwidth_package_id is not None:
            pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        if billing_type is not None:
            pulumi.set(__self__, "billing_type", billing_type)
        if isp is not None:
            pulumi.set(__self__, "isp", isp)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[builtins.int]:
        """
        公网IP的带宽峰值，默认为1，单位：Mbps。取值：当Eip.BillingType取值为PostPaidByBandwidth时，取值为1 ～ 500。当Eip.BillingType取值为PostPaidByTraffic时，取值为1 ～ 200。
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> Optional[builtins.str]:
        """
        共享带宽包的ID，表示将公网IP加入到共享带宽包。 您可以调用 DescribeBandwidthPackages 接口，查询共享带宽包的ID。 公网IP加入到共享带宽包必须同时满足如下条件：二者的安全防护类型相同。二者的线路类型相同。共享带宽包为IPv4类型。
        """
        return pulumi.get(self, "bandwidth_package_id")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> Optional[builtins.str]:
        """
        公网IP的计费类型，取值：PostPaidByBandwidth（默认）：按量计费-按带宽上限计费。PostPaidByTraffic：按量计费-按实际流量计费。
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter
    def isp(self) -> Optional[builtins.str]:
        """
        线路类型，取值：BGP（默认）：BGP线路。若您的账号已申请使用静态单线，ISP还可以传入ChinaMobile（表示中国移动）、ChinaTelecom（表示中国电信）、ChinaUnicom（表示中国联通）。
        """
        return pulumi.get(self, "isp")


@pulumi.output_type
class ScalingConfigurationInstanceTypeOverride(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "instanceType":
            suggest = "instance_type"
        elif key == "priceLimit":
            suggest = "price_limit"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ScalingConfigurationInstanceTypeOverride. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ScalingConfigurationInstanceTypeOverride.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ScalingConfigurationInstanceTypeOverride.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 instance_type: Optional[builtins.str] = None,
                 price_limit: Optional[builtins.float] = None):
        """
        :param builtins.str instance_type: 指定抢占式实例的规格。参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - InstanceType：表示抢占式实例的规格。多个规格之间用&分隔。
        :param builtins.float price_limit: 指定抢占式实例规格每小时的最高价格参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - PriceLimit：表示抢占式实例规格每小时的最高价格。取值：大于0，且最大不超过3位小数。多个价格之间用&分隔。
        """
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if price_limit is not None:
            pulumi.set(__self__, "price_limit", price_limit)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[builtins.str]:
        """
        指定抢占式实例的规格。参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - InstanceType：表示抢占式实例的规格。多个规格之间用&分隔。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="priceLimit")
    def price_limit(self) -> Optional[builtins.float]:
        """
        指定抢占式实例规格每小时的最高价格参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - PriceLimit：表示抢占式实例规格每小时的最高价格。取值：大于0，且最大不超过3位小数。多个价格之间用&分隔。
        """
        return pulumi.get(self, "price_limit")


@pulumi.output_type
class ScalingConfigurationTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class ScalingConfigurationVolume(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "deleteWithInstance":
            suggest = "delete_with_instance"
        elif key == "volumeType":
            suggest = "volume_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ScalingConfigurationVolume. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ScalingConfigurationVolume.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ScalingConfigurationVolume.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 delete_with_instance: Optional[builtins.bool] = None,
                 size: Optional[builtins.int] = None,
                 volume_type: Optional[builtins.str] = None):
        """
        :param builtins.bool delete_with_instance: 云盘是否随实例释放：true（默认值）：云盘随实例释放。false：云盘不随实例释放。取值为false时对系统盘无效，系统盘默认随实例释放，不允许保留。
        :param builtins.int size: 云盘的容量，单位为GiB。系统盘取值范围：10   - 500。数据盘取值范围：10   - 8192。
        :param builtins.str volume_type: 云盘的类型：ESSD*FlexPL：极速型SSDFlexPL。ESSD*PL0：极速型SSD PL0。
        """
        if delete_with_instance is not None:
            pulumi.set(__self__, "delete_with_instance", delete_with_instance)
        if size is not None:
            pulumi.set(__self__, "size", size)
        if volume_type is not None:
            pulumi.set(__self__, "volume_type", volume_type)

    @property
    @pulumi.getter(name="deleteWithInstance")
    def delete_with_instance(self) -> Optional[builtins.bool]:
        """
        云盘是否随实例释放：true（默认值）：云盘随实例释放。false：云盘不随实例释放。取值为false时对系统盘无效，系统盘默认随实例释放，不允许保留。
        """
        return pulumi.get(self, "delete_with_instance")

    @property
    @pulumi.getter
    def size(self) -> Optional[builtins.int]:
        """
        云盘的容量，单位为GiB。系统盘取值范围：10   - 500。数据盘取值范围：10   - 8192。
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> Optional[builtins.str]:
        """
        云盘的类型：ESSD*FlexPL：极速型SSDFlexPL。ESSD*PL0：极速型SSD PL0。
        """
        return pulumi.get(self, "volume_type")


@pulumi.output_type
class ScalingGroupInstancesDistribution(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "compensateWithOnDemand":
            suggest = "compensate_with_on_demand"
        elif key == "onDemandBaseCapacity":
            suggest = "on_demand_base_capacity"
        elif key == "onDemandPercentageAboveBaseCapacity":
            suggest = "on_demand_percentage_above_base_capacity"
        elif key == "spotInstanceRemedy":
            suggest = "spot_instance_remedy"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ScalingGroupInstancesDistribution. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ScalingGroupInstancesDistribution.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ScalingGroupInstancesDistribution.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 compensate_with_on_demand: Optional[builtins.bool] = None,
                 on_demand_base_capacity: Optional[builtins.int] = None,
                 on_demand_percentage_above_base_capacity: Optional[builtins.int] = None,
                 spot_instance_remedy: Optional[builtins.bool] = None):
        """
        :param builtins.bool compensate_with_on_demand: 当因价格、库存等原因无法创建足够的抢占式实例时，是否允许使用按量实例补充抢占式容量。true: 允许。false（默认）: 不允许。
        :param builtins.int on_demand_base_capacity: 伸缩组中按量计费实例个数的最小值，取值范围：0~2000。当组中按量计费实例个数少于该值时，将优先创建按量计费的实例。
        :param builtins.int on_demand_percentage_above_base_capacity: 伸缩组满足最小按量实例数要求后，超出的实例中按量实例应占的比例，取值范围：0～100。
        :param builtins.bool spot_instance_remedy: 是否允许抢占式实例到期替换。开启则表示在抢占式实例被回收前5分钟左右，伸缩组将主动新建新的抢占式实例替换掉当前抢占式实例。true: 允许。false（默认）: 不允许。
        """
        if compensate_with_on_demand is not None:
            pulumi.set(__self__, "compensate_with_on_demand", compensate_with_on_demand)
        if on_demand_base_capacity is not None:
            pulumi.set(__self__, "on_demand_base_capacity", on_demand_base_capacity)
        if on_demand_percentage_above_base_capacity is not None:
            pulumi.set(__self__, "on_demand_percentage_above_base_capacity", on_demand_percentage_above_base_capacity)
        if spot_instance_remedy is not None:
            pulumi.set(__self__, "spot_instance_remedy", spot_instance_remedy)

    @property
    @pulumi.getter(name="compensateWithOnDemand")
    def compensate_with_on_demand(self) -> Optional[builtins.bool]:
        """
        当因价格、库存等原因无法创建足够的抢占式实例时，是否允许使用按量实例补充抢占式容量。true: 允许。false（默认）: 不允许。
        """
        return pulumi.get(self, "compensate_with_on_demand")

    @property
    @pulumi.getter(name="onDemandBaseCapacity")
    def on_demand_base_capacity(self) -> Optional[builtins.int]:
        """
        伸缩组中按量计费实例个数的最小值，取值范围：0~2000。当组中按量计费实例个数少于该值时，将优先创建按量计费的实例。
        """
        return pulumi.get(self, "on_demand_base_capacity")

    @property
    @pulumi.getter(name="onDemandPercentageAboveBaseCapacity")
    def on_demand_percentage_above_base_capacity(self) -> Optional[builtins.int]:
        """
        伸缩组满足最小按量实例数要求后，超出的实例中按量实例应占的比例，取值范围：0～100。
        """
        return pulumi.get(self, "on_demand_percentage_above_base_capacity")

    @property
    @pulumi.getter(name="spotInstanceRemedy")
    def spot_instance_remedy(self) -> Optional[builtins.bool]:
        """
        是否允许抢占式实例到期替换。开启则表示在抢占式实例被回收前5分钟左右，伸缩组将主动新建新的抢占式实例替换掉当前抢占式实例。true: 允许。false（默认）: 不允许。
        """
        return pulumi.get(self, "spot_instance_remedy")


@pulumi.output_type
class ScalingGroupLaunchTemplateOverride(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "instanceType":
            suggest = "instance_type"
        elif key == "priceLimit":
            suggest = "price_limit"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ScalingGroupLaunchTemplateOverride. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ScalingGroupLaunchTemplateOverride.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ScalingGroupLaunchTemplateOverride.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 instance_type: Optional[builtins.str] = None,
                 price_limit: Optional[builtins.float] = None):
        """
        :param builtins.str instance_type: 指定实例规格。本参数仅当LaunchTemplateId参数存在取值时生有效。
        :param builtins.float price_limit: 指定抢占式实例规格每小时的最高价格。本参数仅当LaunchTemplateId参数存在取值，且启动模版的计费模式为设置出价上限的抢占式实例（即SpotWithPriceLimit）时有效。
        """
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if price_limit is not None:
            pulumi.set(__self__, "price_limit", price_limit)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[builtins.str]:
        """
        指定实例规格。本参数仅当LaunchTemplateId参数存在取值时生有效。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="priceLimit")
    def price_limit(self) -> Optional[builtins.float]:
        """
        指定抢占式实例规格每小时的最高价格。本参数仅当LaunchTemplateId参数存在取值，且启动模版的计费模式为设置出价上限的抢占式实例（即SpotWithPriceLimit）时有效。
        """
        return pulumi.get(self, "price_limit")


@pulumi.output_type
class ScalingGroupServerGroupAttribute(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "serverGroupId":
            suggest = "server_group_id"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ScalingGroupServerGroupAttribute. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ScalingGroupServerGroupAttribute.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ScalingGroupServerGroupAttribute.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 port: Optional[builtins.int] = None,
                 server_group_id: Optional[builtins.str] = None,
                 type: Optional[builtins.str] = None,
                 weight: Optional[builtins.int] = None):
        """
        :param builtins.int port: 负载均衡后端服务器组中服务器的端口号。取值1 ～ 65535。
        :param builtins.str server_group_id: 负载均衡后端服务器组的ID。
        :param builtins.str type: 负载均衡服务器组类型。单个CLB/ALB最多支持添加20个后端服务器组，所有CLB/ALB最多支持添加100个后端服务器。ALB：应用型负载均衡。CLB：传统型型负载均衡（默认）。
        :param builtins.int weight: 负载均衡后端服务器组中服务器的权重。
        """
        if port is not None:
            pulumi.set(__self__, "port", port)
        if server_group_id is not None:
            pulumi.set(__self__, "server_group_id", server_group_id)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter
    def port(self) -> Optional[builtins.int]:
        """
        负载均衡后端服务器组中服务器的端口号。取值1 ～ 65535。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> Optional[builtins.str]:
        """
        负载均衡后端服务器组的ID。
        """
        return pulumi.get(self, "server_group_id")

    @property
    @pulumi.getter
    def type(self) -> Optional[builtins.str]:
        """
        负载均衡服务器组类型。单个CLB/ALB最多支持添加20个后端服务器组，所有CLB/ALB最多支持添加100个后端服务器。ALB：应用型负载均衡。CLB：传统型型负载均衡（默认）。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def weight(self) -> Optional[builtins.int]:
        """
        负载均衡后端服务器组中服务器的权重。
        """
        return pulumi.get(self, "weight")


@pulumi.output_type
class ScalingGroupTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str value: 用户标签的标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetScalingConfigurationEipResult(dict):
    def __init__(__self__, *,
                 bandwidth: builtins.int,
                 bandwidth_package_id: builtins.str,
                 billing_type: builtins.str,
                 isp: builtins.str):
        """
        :param builtins.int bandwidth: 公网IP的带宽峰值，默认为1，单位：Mbps。取值：当Eip.BillingType取值为PostPaidByBandwidth时，取值为1 ～ 500。当Eip.BillingType取值为PostPaidByTraffic时，取值为1 ～ 200。
        :param builtins.str bandwidth_package_id: 共享带宽包的ID，表示将公网IP加入到共享带宽包。 您可以调用 DescribeBandwidthPackages 接口，查询共享带宽包的ID。 公网IP加入到共享带宽包必须同时满足如下条件：二者的安全防护类型相同。二者的线路类型相同。共享带宽包为IPv4类型。
        :param builtins.str billing_type: 公网IP的计费类型，取值：PostPaidByBandwidth（默认）：按量计费-按带宽上限计费。PostPaidByTraffic：按量计费-按实际流量计费。
        :param builtins.str isp: 线路类型，取值：BGP（默认）：BGP线路。若您的账号已申请使用静态单线，ISP还可以传入ChinaMobile（表示中国移动）、ChinaTelecom（表示中国电信）、ChinaUnicom（表示中国联通）。
        """
        pulumi.set(__self__, "bandwidth", bandwidth)
        pulumi.set(__self__, "bandwidth_package_id", bandwidth_package_id)
        pulumi.set(__self__, "billing_type", billing_type)
        pulumi.set(__self__, "isp", isp)

    @property
    @pulumi.getter
    def bandwidth(self) -> builtins.int:
        """
        公网IP的带宽峰值，默认为1，单位：Mbps。取值：当Eip.BillingType取值为PostPaidByBandwidth时，取值为1 ～ 500。当Eip.BillingType取值为PostPaidByTraffic时，取值为1 ～ 200。
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="bandwidthPackageId")
    def bandwidth_package_id(self) -> builtins.str:
        """
        共享带宽包的ID，表示将公网IP加入到共享带宽包。 您可以调用 DescribeBandwidthPackages 接口，查询共享带宽包的ID。 公网IP加入到共享带宽包必须同时满足如下条件：二者的安全防护类型相同。二者的线路类型相同。共享带宽包为IPv4类型。
        """
        return pulumi.get(self, "bandwidth_package_id")

    @property
    @pulumi.getter(name="billingType")
    def billing_type(self) -> builtins.str:
        """
        公网IP的计费类型，取值：PostPaidByBandwidth（默认）：按量计费-按带宽上限计费。PostPaidByTraffic：按量计费-按实际流量计费。
        """
        return pulumi.get(self, "billing_type")

    @property
    @pulumi.getter
    def isp(self) -> builtins.str:
        """
        线路类型，取值：BGP（默认）：BGP线路。若您的账号已申请使用静态单线，ISP还可以传入ChinaMobile（表示中国移动）、ChinaTelecom（表示中国电信）、ChinaUnicom（表示中国联通）。
        """
        return pulumi.get(self, "isp")


@pulumi.output_type
class GetScalingConfigurationInstanceTypeOverrideResult(dict):
    def __init__(__self__, *,
                 instance_type: builtins.str,
                 price_limit: builtins.float):
        """
        :param builtins.str instance_type: 指定抢占式实例的规格。参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - InstanceType：表示抢占式实例的规格。多个规格之间用&分隔。
        :param builtins.float price_limit: 指定抢占式实例规格每小时的最高价格参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - PriceLimit：表示抢占式实例规格每小时的最高价格。取值：大于0，且最大不超过3位小数。多个价格之间用&分隔。
        """
        pulumi.set(__self__, "instance_type", instance_type)
        pulumi.set(__self__, "price_limit", price_limit)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> builtins.str:
        """
        指定抢占式实例的规格。参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - InstanceType：表示抢占式实例的规格。多个规格之间用&分隔。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="priceLimit")
    def price_limit(self) -> builtins.float:
        """
        指定抢占式实例规格每小时的最高价格参数   - N：表示实例规格的序号，取值为1 ～ 10。取值   - PriceLimit：表示抢占式实例规格每小时的最高价格。取值：大于0，且最大不超过3位小数。多个价格之间用&分隔。
        """
        return pulumi.get(self, "price_limit")


@pulumi.output_type
class GetScalingConfigurationTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetScalingConfigurationVolumeResult(dict):
    def __init__(__self__, *,
                 delete_with_instance: builtins.bool,
                 size: builtins.int,
                 volume_type: builtins.str):
        """
        :param builtins.bool delete_with_instance: 云盘是否随实例释放：true（默认值）：云盘随实例释放。false：云盘不随实例释放。取值为false时对系统盘无效，系统盘默认随实例释放，不允许保留。
        :param builtins.int size: 云盘的容量，单位为GiB。系统盘取值范围：10   - 500。数据盘取值范围：10   - 8192。
        :param builtins.str volume_type: 云盘的类型：ESSD*FlexPL：极速型SSDFlexPL。ESSD*PL0：极速型SSD PL0。
        """
        pulumi.set(__self__, "delete_with_instance", delete_with_instance)
        pulumi.set(__self__, "size", size)
        pulumi.set(__self__, "volume_type", volume_type)

    @property
    @pulumi.getter(name="deleteWithInstance")
    def delete_with_instance(self) -> builtins.bool:
        """
        云盘是否随实例释放：true（默认值）：云盘随实例释放。false：云盘不随实例释放。取值为false时对系统盘无效，系统盘默认随实例释放，不允许保留。
        """
        return pulumi.get(self, "delete_with_instance")

    @property
    @pulumi.getter
    def size(self) -> builtins.int:
        """
        云盘的容量，单位为GiB。系统盘取值范围：10   - 500。数据盘取值范围：10   - 8192。
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter(name="volumeType")
    def volume_type(self) -> builtins.str:
        """
        云盘的类型：ESSD*FlexPL：极速型SSDFlexPL。ESSD*PL0：极速型SSD PL0。
        """
        return pulumi.get(self, "volume_type")


@pulumi.output_type
class GetScalingGroupInstancesDistributionResult(dict):
    def __init__(__self__, *,
                 compensate_with_on_demand: builtins.bool,
                 on_demand_base_capacity: builtins.int,
                 on_demand_percentage_above_base_capacity: builtins.int,
                 spot_instance_remedy: builtins.bool):
        """
        :param builtins.bool compensate_with_on_demand: 当因价格、库存等原因无法创建足够的抢占式实例时，是否允许使用按量实例补充抢占式容量。true: 允许。false（默认）: 不允许。
        :param builtins.int on_demand_base_capacity: 伸缩组中按量计费实例个数的最小值，取值范围：0~2000。当组中按量计费实例个数少于该值时，将优先创建按量计费的实例。
        :param builtins.int on_demand_percentage_above_base_capacity: 伸缩组满足最小按量实例数要求后，超出的实例中按量实例应占的比例，取值范围：0～100。
        :param builtins.bool spot_instance_remedy: 是否允许抢占式实例到期替换。开启则表示在抢占式实例被回收前5分钟左右，伸缩组将主动新建新的抢占式实例替换掉当前抢占式实例。true: 允许。false（默认）: 不允许。
        """
        pulumi.set(__self__, "compensate_with_on_demand", compensate_with_on_demand)
        pulumi.set(__self__, "on_demand_base_capacity", on_demand_base_capacity)
        pulumi.set(__self__, "on_demand_percentage_above_base_capacity", on_demand_percentage_above_base_capacity)
        pulumi.set(__self__, "spot_instance_remedy", spot_instance_remedy)

    @property
    @pulumi.getter(name="compensateWithOnDemand")
    def compensate_with_on_demand(self) -> builtins.bool:
        """
        当因价格、库存等原因无法创建足够的抢占式实例时，是否允许使用按量实例补充抢占式容量。true: 允许。false（默认）: 不允许。
        """
        return pulumi.get(self, "compensate_with_on_demand")

    @property
    @pulumi.getter(name="onDemandBaseCapacity")
    def on_demand_base_capacity(self) -> builtins.int:
        """
        伸缩组中按量计费实例个数的最小值，取值范围：0~2000。当组中按量计费实例个数少于该值时，将优先创建按量计费的实例。
        """
        return pulumi.get(self, "on_demand_base_capacity")

    @property
    @pulumi.getter(name="onDemandPercentageAboveBaseCapacity")
    def on_demand_percentage_above_base_capacity(self) -> builtins.int:
        """
        伸缩组满足最小按量实例数要求后，超出的实例中按量实例应占的比例，取值范围：0～100。
        """
        return pulumi.get(self, "on_demand_percentage_above_base_capacity")

    @property
    @pulumi.getter(name="spotInstanceRemedy")
    def spot_instance_remedy(self) -> builtins.bool:
        """
        是否允许抢占式实例到期替换。开启则表示在抢占式实例被回收前5分钟左右，伸缩组将主动新建新的抢占式实例替换掉当前抢占式实例。true: 允许。false（默认）: 不允许。
        """
        return pulumi.get(self, "spot_instance_remedy")


@pulumi.output_type
class GetScalingGroupLaunchTemplateOverrideResult(dict):
    def __init__(__self__, *,
                 instance_type: builtins.str,
                 price_limit: builtins.float,
                 weighted_capacity: builtins.int):
        """
        :param builtins.str instance_type: 指定实例规格。本参数仅当LaunchTemplateId参数存在取值时生有效。
        :param builtins.float price_limit: 指定抢占式实例规格每小时的最高价格。本参数仅当LaunchTemplateId参数存在取值，且启动模版的计费模式为设置出价上限的抢占式实例（即SpotWithPriceLimit）时有效。
        :param builtins.int weighted_capacity: 实例规格的权重。
        """
        pulumi.set(__self__, "instance_type", instance_type)
        pulumi.set(__self__, "price_limit", price_limit)
        pulumi.set(__self__, "weighted_capacity", weighted_capacity)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> builtins.str:
        """
        指定实例规格。本参数仅当LaunchTemplateId参数存在取值时生有效。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="priceLimit")
    def price_limit(self) -> builtins.float:
        """
        指定抢占式实例规格每小时的最高价格。本参数仅当LaunchTemplateId参数存在取值，且启动模版的计费模式为设置出价上限的抢占式实例（即SpotWithPriceLimit）时有效。
        """
        return pulumi.get(self, "price_limit")

    @property
    @pulumi.getter(name="weightedCapacity")
    def weighted_capacity(self) -> builtins.int:
        """
        实例规格的权重。
        """
        return pulumi.get(self, "weighted_capacity")


@pulumi.output_type
class GetScalingGroupServerGroupAttributeResult(dict):
    def __init__(__self__, *,
                 load_balancer_id: builtins.str,
                 port: builtins.int,
                 server_group_id: builtins.str,
                 type: builtins.str,
                 weight: builtins.int):
        """
        :param builtins.str load_balancer_id: 负载均衡实例的ID。
        :param builtins.int port: 负载均衡后端服务器组中服务器的端口号。取值1 ～ 65535。
        :param builtins.str server_group_id: 负载均衡后端服务器组的ID。
        :param builtins.str type: 负载均衡服务器组类型。单个CLB/ALB最多支持添加20个后端服务器组，所有CLB/ALB最多支持添加100个后端服务器。ALB：应用型负载均衡。CLB：传统型型负载均衡（默认）。
        :param builtins.int weight: 负载均衡后端服务器组中服务器的权重。
        """
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        pulumi.set(__self__, "port", port)
        pulumi.set(__self__, "server_group_id", server_group_id)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> builtins.str:
        """
        负载均衡实例的ID。
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter
    def port(self) -> builtins.int:
        """
        负载均衡后端服务器组中服务器的端口号。取值1 ～ 65535。
        """
        return pulumi.get(self, "port")

    @property
    @pulumi.getter(name="serverGroupId")
    def server_group_id(self) -> builtins.str:
        """
        负载均衡后端服务器组的ID。
        """
        return pulumi.get(self, "server_group_id")

    @property
    @pulumi.getter
    def type(self) -> builtins.str:
        """
        负载均衡服务器组类型。单个CLB/ALB最多支持添加20个后端服务器组，所有CLB/ALB最多支持添加100个后端服务器。ALB：应用型负载均衡。CLB：传统型型负载均衡（默认）。
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter
    def weight(self) -> builtins.int:
        """
        负载均衡后端服务器组中服务器的权重。
        """
        return pulumi.get(self, "weight")


@pulumi.output_type
class GetScalingGroupTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 用户标签的标签键。
        :param builtins.str value: 用户标签的标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        用户标签的标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        用户标签的标签值。
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetKeyRingResult',
    'AwaitableGetKeyRingResult',
    'get_key_ring',
    'get_key_ring_output',
]

@pulumi.output_type
class GetKeyRingResult:
    """
    A collection of values returned by getKeyRing.
    """
    def __init__(__self__, create_date=None, description=None, id=None, key_count=None, key_ring_id=None, keyring_name=None, keyring_type=None, project_name=None, uid=None, update_date=None):
        if create_date and not isinstance(create_date, int):
            raise TypeError("Expected argument 'create_date' to be a int")
        pulumi.set(__self__, "create_date", create_date)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if key_count and not isinstance(key_count, int):
            raise TypeError("Expected argument 'key_count' to be a int")
        pulumi.set(__self__, "key_count", key_count)
        if key_ring_id and not isinstance(key_ring_id, str):
            raise TypeError("Expected argument 'key_ring_id' to be a str")
        pulumi.set(__self__, "key_ring_id", key_ring_id)
        if keyring_name and not isinstance(keyring_name, str):
            raise TypeError("Expected argument 'keyring_name' to be a str")
        pulumi.set(__self__, "keyring_name", keyring_name)
        if keyring_type and not isinstance(keyring_type, str):
            raise TypeError("Expected argument 'keyring_type' to be a str")
        pulumi.set(__self__, "keyring_type", keyring_type)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if uid and not isinstance(uid, str):
            raise TypeError("Expected argument 'uid' to be a str")
        pulumi.set(__self__, "uid", uid)
        if update_date and not isinstance(update_date, int):
            raise TypeError("Expected argument 'update_date' to be a int")
        pulumi.set(__self__, "update_date", update_date)

    @property
    @pulumi.getter(name="createDate")
    def create_date(self) -> builtins.int:
        """
        密钥环创建日期。
        """
        return pulumi.get(self, "create_date")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        密钥环描述，长度为 0   - 8192 个字符。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="keyCount")
    def key_count(self) -> builtins.int:
        """
        密钥环密钥次数。
        """
        return pulumi.get(self, "key_count")

    @property
    @pulumi.getter(name="keyRingId")
    def key_ring_id(self) -> builtins.str:
        """
        密钥环唯一标识符，UUID形式。
        """
        return pulumi.get(self, "key_ring_id")

    @property
    @pulumi.getter(name="keyringName")
    def keyring_name(self) -> builtins.str:
        """
        密钥环名称，长度为 2   - 31 个字符。合法字符：[a-zA-Z0-9-_]。
        """
        return pulumi.get(self, "keyring_name")

    @property
    @pulumi.getter(name="keyringType")
    def keyring_type(self) -> builtins.str:
        """
        密钥环类型，取值：CustomKeyring。
        """
        return pulumi.get(self, "keyring_type")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        项目名称，默认值：default。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def uid(self) -> builtins.str:
        """
        密钥环租户ID。
        """
        return pulumi.get(self, "uid")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> builtins.int:
        """
        密钥环更新日期。
        """
        return pulumi.get(self, "update_date")


class AwaitableGetKeyRingResult(GetKeyRingResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetKeyRingResult(
            create_date=self.create_date,
            description=self.description,
            id=self.id,
            key_count=self.key_count,
            key_ring_id=self.key_ring_id,
            keyring_name=self.keyring_name,
            keyring_type=self.keyring_type,
            project_name=self.project_name,
            uid=self.uid,
            update_date=self.update_date)


def get_key_ring(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetKeyRingResult:
    """
    Data Source schema for Byteplus::KMS::KeyRing


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:kms/getKeyRing:getKeyRing', __args__, opts=opts, typ=GetKeyRingResult).value

    return AwaitableGetKeyRingResult(
        create_date=pulumi.get(__ret__, 'create_date'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        key_count=pulumi.get(__ret__, 'key_count'),
        key_ring_id=pulumi.get(__ret__, 'key_ring_id'),
        keyring_name=pulumi.get(__ret__, 'keyring_name'),
        keyring_type=pulumi.get(__ret__, 'keyring_type'),
        project_name=pulumi.get(__ret__, 'project_name'),
        uid=pulumi.get(__ret__, 'uid'),
        update_date=pulumi.get(__ret__, 'update_date'))
def get_key_ring_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetKeyRingResult]:
    """
    Data Source schema for Byteplus::KMS::KeyRing


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:kms/getKeyRing:getKeyRing', __args__, opts=opts, typ=GetKeyRingResult)
    return __ret__.apply(lambda __response__: GetKeyRingResult(
        create_date=pulumi.get(__response__, 'create_date'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        key_count=pulumi.get(__response__, 'key_count'),
        key_ring_id=pulumi.get(__response__, 'key_ring_id'),
        keyring_name=pulumi.get(__response__, 'keyring_name'),
        keyring_type=pulumi.get(__response__, 'keyring_type'),
        project_name=pulumi.get(__response__, 'project_name'),
        uid=pulumi.get(__response__, 'uid'),
        update_date=pulumi.get(__response__, 'update_date')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['VpnAttachmentArgs', 'VpnAttachment']

@pulumi.input_type
class VpnAttachmentArgs:
    def __init__(__self__, *,
                 transit_router_id: pulumi.Input[builtins.str],
                 vpn_connection_id: pulumi.Input[builtins.str],
                 zone_id: pulumi.Input[builtins.str],
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_revoke_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VpnAttachmentTagArgs']]]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        The set of arguments for constructing a VpnAttachment resource.
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID。
        :param pulumi.Input[builtins.str] vpn_connection_id: IPsec连接的ID。
        :param pulumi.Input[builtins.str] zone_id: IPsec连接所属可用区的ID。
        :param pulumi.Input[builtins.str] description: 网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.bool] health_check_revoke_route_enabled: 是否开启健康检查收敛路由功能。true：是。仅当IPsec连接开启健康检查功能时生效，且只支持收敛静态路由，不支持收敛BGP路由。false：否。
        :param pulumi.Input[builtins.str] transit_router_attachment_name: 网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        :param pulumi.Input[builtins.str] transit_router_route_table_id: 关联的TR路由表ID。
        """
        pulumi.set(__self__, "transit_router_id", transit_router_id)
        pulumi.set(__self__, "vpn_connection_id", vpn_connection_id)
        pulumi.set(__self__, "zone_id", zone_id)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if health_check_revoke_route_enabled is not None:
            pulumi.set(__self__, "health_check_revoke_route_enabled", health_check_revoke_route_enabled)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_attachment_name is not None:
            pulumi.set(__self__, "transit_router_attachment_name", transit_router_attachment_name)
        if transit_router_route_table_id is not None:
            pulumi.set(__self__, "transit_router_route_table_id", transit_router_route_table_id)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Input[builtins.str]:
        """
        中转路由器实例的ID。
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter(name="vpnConnectionId")
    def vpn_connection_id(self) -> pulumi.Input[builtins.str]:
        """
        IPsec连接的ID。
        """
        return pulumi.get(self, "vpn_connection_id")

    @vpn_connection_id.setter
    def vpn_connection_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "vpn_connection_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Input[builtins.str]:
        """
        IPsec连接所属可用区的ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "zone_id", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="healthCheckRevokeRouteEnabled")
    def health_check_revoke_route_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启健康检查收敛路由功能。true：是。仅当IPsec连接开启健康检查功能时生效，且只支持收敛静态路由，不支持收敛BGP路由。false：否。
        """
        return pulumi.get(self, "health_check_revoke_route_enabled")

    @health_check_revoke_route_enabled.setter
    def health_check_revoke_route_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "health_check_revoke_route_enabled", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VpnAttachmentTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VpnAttachmentTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    def transit_router_attachment_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @transit_router_attachment_name.setter
    def transit_router_attachment_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_name", value)

    @property
    @pulumi.getter(name="transitRouterRouteTableId")
    def transit_router_route_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        关联的TR路由表ID。
        """
        return pulumi.get(self, "transit_router_route_table_id")

    @transit_router_route_table_id.setter
    def transit_router_route_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_table_id", value)


@pulumi.input_type
class _VpnAttachmentState:
    def __init__(__self__, *,
                 auto_publish_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_revoke_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 ipv6_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 status: Optional[pulumi.Input[builtins.str]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input['VpnAttachmentTagArgs']]]] = None,
                 transit_router_attachment_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 vpn_connection_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering VpnAttachment resources.
        :param pulumi.Input[builtins.bool] auto_publish_route_enabled: 是否自动同步TR路由到网络实例路由表中。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.bool] health_check_revoke_route_enabled: 是否开启健康检查收敛路由功能。true：是。仅当IPsec连接开启健康检查功能时生效，且只支持收敛静态路由，不支持收敛BGP路由。false：否。
        :param pulumi.Input[builtins.bool] ipv6_enabled: 是否开启IPv6功能。
        :param pulumi.Input[builtins.str] status: 网络实例连接的状态。Creating：创建中。Deleting：删除中。Pending：配置中。Available：可用。
        :param pulumi.Input[builtins.str] transit_router_attachment_id: 网络实例连接的ID。
        :param pulumi.Input[builtins.str] transit_router_attachment_name: 网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID。
        :param pulumi.Input[builtins.str] transit_router_route_table_id: 关联的TR路由表ID。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        :param pulumi.Input[builtins.str] vpn_connection_id: IPsec连接的ID。
        :param pulumi.Input[builtins.str] zone_id: IPsec连接所属可用区的ID。
        """
        if auto_publish_route_enabled is not None:
            pulumi.set(__self__, "auto_publish_route_enabled", auto_publish_route_enabled)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if health_check_revoke_route_enabled is not None:
            pulumi.set(__self__, "health_check_revoke_route_enabled", health_check_revoke_route_enabled)
        if ipv6_enabled is not None:
            pulumi.set(__self__, "ipv6_enabled", ipv6_enabled)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if tags is not None:
            pulumi.set(__self__, "tags", tags)
        if transit_router_attachment_id is not None:
            pulumi.set(__self__, "transit_router_attachment_id", transit_router_attachment_id)
        if transit_router_attachment_name is not None:
            pulumi.set(__self__, "transit_router_attachment_name", transit_router_attachment_name)
        if transit_router_id is not None:
            pulumi.set(__self__, "transit_router_id", transit_router_id)
        if transit_router_route_table_id is not None:
            pulumi.set(__self__, "transit_router_route_table_id", transit_router_route_table_id)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if vpn_connection_id is not None:
            pulumi.set(__self__, "vpn_connection_id", vpn_connection_id)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="autoPublishRouteEnabled")
    def auto_publish_route_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否自动同步TR路由到网络实例路由表中。
        """
        return pulumi.get(self, "auto_publish_route_enabled")

    @auto_publish_route_enabled.setter
    def auto_publish_route_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_publish_route_enabled", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="healthCheckRevokeRouteEnabled")
    def health_check_revoke_route_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启健康检查收敛路由功能。true：是。仅当IPsec连接开启健康检查功能时生效，且只支持收敛静态路由，不支持收敛BGP路由。false：否。
        """
        return pulumi.get(self, "health_check_revoke_route_enabled")

    @health_check_revoke_route_enabled.setter
    def health_check_revoke_route_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "health_check_revoke_route_enabled", value)

    @property
    @pulumi.getter(name="ipv6Enabled")
    def ipv6_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启IPv6功能。
        """
        return pulumi.get(self, "ipv6_enabled")

    @ipv6_enabled.setter
    def ipv6_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ipv6_enabled", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的状态。Creating：创建中。Deleting：删除中。Pending：配置中。Available：可用。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter
    def tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['VpnAttachmentTagArgs']]]]:
        return pulumi.get(self, "tags")

    @tags.setter
    def tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['VpnAttachmentTagArgs']]]]):
        pulumi.set(self, "tags", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentId")
    def transit_router_attachment_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的ID。
        """
        return pulumi.get(self, "transit_router_attachment_id")

    @transit_router_attachment_id.setter
    def transit_router_attachment_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_id", value)

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    def transit_router_attachment_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @transit_router_attachment_name.setter
    def transit_router_attachment_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_attachment_name", value)

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        中转路由器实例的ID。
        """
        return pulumi.get(self, "transit_router_id")

    @transit_router_id.setter
    def transit_router_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_id", value)

    @property
    @pulumi.getter(name="transitRouterRouteTableId")
    def transit_router_route_table_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        关联的TR路由表ID。
        """
        return pulumi.get(self, "transit_router_route_table_id")

    @transit_router_route_table_id.setter
    def transit_router_route_table_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "transit_router_route_table_id", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="vpnConnectionId")
    def vpn_connection_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPsec连接的ID。
        """
        return pulumi.get(self, "vpn_connection_id")

    @vpn_connection_id.setter
    def vpn_connection_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "vpn_connection_id", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        IPsec连接所属可用区的ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("bytepluscc:transitrouter/vpnAttachment:VpnAttachment")
class VpnAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_revoke_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpnAttachmentTagArgs', 'VpnAttachmentTagArgsDict']]]]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpn_connection_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        通过在VPN连接的IPsec连接和中转路由器之间建立连接，可以实现VPN连通的网络与中转路由器的私网互通。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        transit_router_vpn_attachment_demo = bytepluscc.transitrouter.VpnAttachment("TransitRouterVpnAttachmentDemo",
            description="test",
            tags=[{
                "key": "env",
                "value": "test",
            }],
            transit_router_attachment_name="ccapi-test-1",
            transit_router_id="tr-mjl8zkxxxxxsmt1boobol4",
            transit_router_route_table_id="tr-rtb-mjlxxxxxo5smt1bnewrhh",
            vpn_connection_id="vgc-ij0yxxxxx474o8cux0n08t",
            zone_id="cn-beijing-a")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:transitrouter/vpnAttachment:VpnAttachment example "transit_router_id|transit_router_attachment_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] description: 网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.bool] health_check_revoke_route_enabled: 是否开启健康检查收敛路由功能。true：是。仅当IPsec连接开启健康检查功能时生效，且只支持收敛静态路由，不支持收敛BGP路由。false：否。
        :param pulumi.Input[builtins.str] transit_router_attachment_name: 网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID。
        :param pulumi.Input[builtins.str] transit_router_route_table_id: 关联的TR路由表ID。
        :param pulumi.Input[builtins.str] vpn_connection_id: IPsec连接的ID。
        :param pulumi.Input[builtins.str] zone_id: IPsec连接所属可用区的ID。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: VpnAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        通过在VPN连接的IPsec连接和中转路由器之间建立连接，可以实现VPN连通的网络与中转路由器的私网互通。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        transit_router_vpn_attachment_demo = bytepluscc.transitrouter.VpnAttachment("TransitRouterVpnAttachmentDemo",
            description="test",
            tags=[{
                "key": "env",
                "value": "test",
            }],
            transit_router_attachment_name="ccapi-test-1",
            transit_router_id="tr-mjl8zkxxxxxsmt1boobol4",
            transit_router_route_table_id="tr-rtb-mjlxxxxxo5smt1bnewrhh",
            vpn_connection_id="vgc-ij0yxxxxx474o8cux0n08t",
            zone_id="cn-beijing-a")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:transitrouter/vpnAttachment:VpnAttachment example "transit_router_id|transit_router_attachment_id"
        ```

        :param str resource_name: The name of the resource.
        :param VpnAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(VpnAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 health_check_revoke_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpnAttachmentTagArgs', 'VpnAttachmentTagArgsDict']]]]] = None,
                 transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
                 transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
                 vpn_connection_id: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = VpnAttachmentArgs.__new__(VpnAttachmentArgs)

            __props__.__dict__["description"] = description
            __props__.__dict__["health_check_revoke_route_enabled"] = health_check_revoke_route_enabled
            __props__.__dict__["tags"] = tags
            __props__.__dict__["transit_router_attachment_name"] = transit_router_attachment_name
            if transit_router_id is None and not opts.urn:
                raise TypeError("Missing required property 'transit_router_id'")
            __props__.__dict__["transit_router_id"] = transit_router_id
            __props__.__dict__["transit_router_route_table_id"] = transit_router_route_table_id
            if vpn_connection_id is None and not opts.urn:
                raise TypeError("Missing required property 'vpn_connection_id'")
            __props__.__dict__["vpn_connection_id"] = vpn_connection_id
            if zone_id is None and not opts.urn:
                raise TypeError("Missing required property 'zone_id'")
            __props__.__dict__["zone_id"] = zone_id
            __props__.__dict__["auto_publish_route_enabled"] = None
            __props__.__dict__["created_time"] = None
            __props__.__dict__["ipv6_enabled"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["transit_router_attachment_id"] = None
            __props__.__dict__["updated_time"] = None
        super(VpnAttachment, __self__).__init__(
            'bytepluscc:transitrouter/vpnAttachment:VpnAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            auto_publish_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            health_check_revoke_route_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            ipv6_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            status: Optional[pulumi.Input[builtins.str]] = None,
            tags: Optional[pulumi.Input[Sequence[pulumi.Input[Union['VpnAttachmentTagArgs', 'VpnAttachmentTagArgsDict']]]]] = None,
            transit_router_attachment_id: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_attachment_name: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_id: Optional[pulumi.Input[builtins.str]] = None,
            transit_router_route_table_id: Optional[pulumi.Input[builtins.str]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            vpn_connection_id: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'VpnAttachment':
        """
        Get an existing VpnAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto_publish_route_enabled: 是否自动同步TR路由到网络实例路由表中。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] description: 网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        :param pulumi.Input[builtins.bool] health_check_revoke_route_enabled: 是否开启健康检查收敛路由功能。true：是。仅当IPsec连接开启健康检查功能时生效，且只支持收敛静态路由，不支持收敛BGP路由。false：否。
        :param pulumi.Input[builtins.bool] ipv6_enabled: 是否开启IPv6功能。
        :param pulumi.Input[builtins.str] status: 网络实例连接的状态。Creating：创建中。Deleting：删除中。Pending：配置中。Available：可用。
        :param pulumi.Input[builtins.str] transit_router_attachment_id: 网络实例连接的ID。
        :param pulumi.Input[builtins.str] transit_router_attachment_name: 网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        :param pulumi.Input[builtins.str] transit_router_id: 中转路由器实例的ID。
        :param pulumi.Input[builtins.str] transit_router_route_table_id: 关联的TR路由表ID。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        :param pulumi.Input[builtins.str] vpn_connection_id: IPsec连接的ID。
        :param pulumi.Input[builtins.str] zone_id: IPsec连接所属可用区的ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _VpnAttachmentState.__new__(_VpnAttachmentState)

        __props__.__dict__["auto_publish_route_enabled"] = auto_publish_route_enabled
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["description"] = description
        __props__.__dict__["health_check_revoke_route_enabled"] = health_check_revoke_route_enabled
        __props__.__dict__["ipv6_enabled"] = ipv6_enabled
        __props__.__dict__["status"] = status
        __props__.__dict__["tags"] = tags
        __props__.__dict__["transit_router_attachment_id"] = transit_router_attachment_id
        __props__.__dict__["transit_router_attachment_name"] = transit_router_attachment_name
        __props__.__dict__["transit_router_id"] = transit_router_id
        __props__.__dict__["transit_router_route_table_id"] = transit_router_route_table_id
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["vpn_connection_id"] = vpn_connection_id
        __props__.__dict__["zone_id"] = zone_id
        return VpnAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="autoPublishRouteEnabled")
    def auto_publish_route_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否自动同步TR路由到网络实例路由表中。
        """
        return pulumi.get(self, "auto_publish_route_enabled")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        网络实例连接的描述信息。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：英文逗号（,）、点号（.）、下划线（_）、空格（ ）、等号（=）、短横线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ~ 255个字符。不传入该参数或该参数不传入数值时，默认为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="healthCheckRevokeRouteEnabled")
    def health_check_revoke_route_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启健康检查收敛路由功能。true：是。仅当IPsec连接开启健康检查功能时生效，且只支持收敛静态路由，不支持收敛BGP路由。false：否。
        """
        return pulumi.get(self, "health_check_revoke_route_enabled")

    @property
    @pulumi.getter(name="ipv6Enabled")
    def ipv6_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启IPv6功能。
        """
        return pulumi.get(self, "ipv6_enabled")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[builtins.str]:
        """
        网络实例连接的状态。Creating：创建中。Deleting：删除中。Pending：配置中。Available：可用。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> pulumi.Output[Sequence['outputs.VpnAttachmentTag']]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="transitRouterAttachmentId")
    def transit_router_attachment_id(self) -> pulumi.Output[builtins.str]:
        """
        网络实例连接的ID。
        """
        return pulumi.get(self, "transit_router_attachment_id")

    @property
    @pulumi.getter(name="transitRouterAttachmentName")
    def transit_router_attachment_name(self) -> pulumi.Output[builtins.str]:
        """
        网络实例连接的名称。必须以字母、数字或中文开头，可包含字母、数字、中文和以下特殊字符：点号（.）、下划线（_）和短横线（-）。长度限制为1 ~ 128个字符。不传入该参数或该参数不传入数值时，默认为网络实例连接的ID。
        """
        return pulumi.get(self, "transit_router_attachment_name")

    @property
    @pulumi.getter(name="transitRouterId")
    def transit_router_id(self) -> pulumi.Output[builtins.str]:
        """
        中转路由器实例的ID。
        """
        return pulumi.get(self, "transit_router_id")

    @property
    @pulumi.getter(name="transitRouterRouteTableId")
    def transit_router_route_table_id(self) -> pulumi.Output[builtins.str]:
        """
        关联的TR路由表ID。
        """
        return pulumi.get(self, "transit_router_route_table_id")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="vpnConnectionId")
    def vpn_connection_id(self) -> pulumi.Output[builtins.str]:
        """
        IPsec连接的ID。
        """
        return pulumi.get(self, "vpn_connection_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        IPsec连接所属可用区的ID。
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'AccountSecureContactInfo',
    'AccountTag',
    'GetAccountSecureContactInfoResult',
    'GetAccountTagResult',
]

@pulumi.output_type
class AccountSecureContactInfo(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "emailVerified":
            suggest = "email_verified"
        elif key == "newEmail":
            suggest = "new_email"
        elif key == "newPhone":
            suggest = "new_phone"
        elif key == "phoneVerified":
            suggest = "phone_verified"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in AccountSecureContactInfo. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        AccountSecureContactInfo.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        AccountSecureContactInfo.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 email: Optional[builtins.str] = None,
                 email_verified: Optional[builtins.int] = None,
                 new_email: Optional[builtins.str] = None,
                 new_phone: Optional[builtins.str] = None,
                 phone: Optional[builtins.str] = None,
                 phone_verified: Optional[builtins.int] = None):
        """
        :param builtins.str email: 安全邮箱。
        :param builtins.int email_verified: 安全邮箱是否验证，1: 未验证，2: 已验证。
        :param builtins.str new_email: 变更中的新邮箱。
        :param builtins.str new_phone: 变更中的新手机号。
        :param builtins.str phone: 安全手机号。
        :param builtins.int phone_verified: 安全手机号是否验证，1: 未验证，2: 已验证。
        """
        if email is not None:
            pulumi.set(__self__, "email", email)
        if email_verified is not None:
            pulumi.set(__self__, "email_verified", email_verified)
        if new_email is not None:
            pulumi.set(__self__, "new_email", new_email)
        if new_phone is not None:
            pulumi.set(__self__, "new_phone", new_phone)
        if phone is not None:
            pulumi.set(__self__, "phone", phone)
        if phone_verified is not None:
            pulumi.set(__self__, "phone_verified", phone_verified)

    @property
    @pulumi.getter
    def email(self) -> Optional[builtins.str]:
        """
        安全邮箱。
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="emailVerified")
    def email_verified(self) -> Optional[builtins.int]:
        """
        安全邮箱是否验证，1: 未验证，2: 已验证。
        """
        return pulumi.get(self, "email_verified")

    @property
    @pulumi.getter(name="newEmail")
    def new_email(self) -> Optional[builtins.str]:
        """
        变更中的新邮箱。
        """
        return pulumi.get(self, "new_email")

    @property
    @pulumi.getter(name="newPhone")
    def new_phone(self) -> Optional[builtins.str]:
        """
        变更中的新手机号。
        """
        return pulumi.get(self, "new_phone")

    @property
    @pulumi.getter
    def phone(self) -> Optional[builtins.str]:
        """
        安全手机号。
        """
        return pulumi.get(self, "phone")

    @property
    @pulumi.getter(name="phoneVerified")
    def phone_verified(self) -> Optional[builtins.int]:
        """
        安全手机号是否验证，1: 未验证，2: 已验证。
        """
        return pulumi.get(self, "phone_verified")


@pulumi.output_type
class AccountTag(dict):
    def __init__(__self__, *,
                 key: Optional[builtins.str] = None,
                 value: Optional[builtins.str] = None):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        if key is not None:
            pulumi.set(__self__, "key", key)
        if value is not None:
            pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> Optional[builtins.str]:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> Optional[builtins.str]:
        """
        标签值。
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetAccountSecureContactInfoResult(dict):
    def __init__(__self__, *,
                 email: builtins.str,
                 email_verified: builtins.int,
                 new_email: builtins.str,
                 new_phone: builtins.str,
                 phone: builtins.str,
                 phone_verified: builtins.int):
        """
        :param builtins.str email: 安全邮箱。
        :param builtins.int email_verified: 安全邮箱是否验证，1: 未验证，2: 已验证。
        :param builtins.str new_email: 变更中的新邮箱。
        :param builtins.str new_phone: 变更中的新手机号。
        :param builtins.str phone: 安全手机号。
        :param builtins.int phone_verified: 安全手机号是否验证，1: 未验证，2: 已验证。
        """
        pulumi.set(__self__, "email", email)
        pulumi.set(__self__, "email_verified", email_verified)
        pulumi.set(__self__, "new_email", new_email)
        pulumi.set(__self__, "new_phone", new_phone)
        pulumi.set(__self__, "phone", phone)
        pulumi.set(__self__, "phone_verified", phone_verified)

    @property
    @pulumi.getter
    def email(self) -> builtins.str:
        """
        安全邮箱。
        """
        return pulumi.get(self, "email")

    @property
    @pulumi.getter(name="emailVerified")
    def email_verified(self) -> builtins.int:
        """
        安全邮箱是否验证，1: 未验证，2: 已验证。
        """
        return pulumi.get(self, "email_verified")

    @property
    @pulumi.getter(name="newEmail")
    def new_email(self) -> builtins.str:
        """
        变更中的新邮箱。
        """
        return pulumi.get(self, "new_email")

    @property
    @pulumi.getter(name="newPhone")
    def new_phone(self) -> builtins.str:
        """
        变更中的新手机号。
        """
        return pulumi.get(self, "new_phone")

    @property
    @pulumi.getter
    def phone(self) -> builtins.str:
        """
        安全手机号。
        """
        return pulumi.get(self, "phone")

    @property
    @pulumi.getter(name="phoneVerified")
    def phone_verified(self) -> builtins.int:
        """
        安全手机号是否验证，1: 未验证，2: 已验证。
        """
        return pulumi.get(self, "phone_verified")


@pulumi.output_type
class GetAccountTagResult(dict):
    def __init__(__self__, *,
                 key: builtins.str,
                 value: builtins.str):
        """
        :param builtins.str key: 标签键。
        :param builtins.str value: 标签值。
        """
        pulumi.set(__self__, "key", key)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def key(self) -> builtins.str:
        """
        标签键。
        """
        return pulumi.get(self, "key")

    @property
    @pulumi.getter
    def value(self) -> builtins.str:
        """
        标签值。
        """
        return pulumi.get(self, "value")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetTrafficMirrorTargetResult',
    'AwaitableGetTrafficMirrorTargetResult',
    'get_traffic_mirror_target',
    'get_traffic_mirror_target_output',
]

@pulumi.output_type
class GetTrafficMirrorTargetResult:
    """
    A collection of values returned by getTrafficMirrorTarget.
    """
    def __init__(__self__, created_at=None, description=None, id=None, instance_id=None, instance_type=None, project_name=None, status=None, tags=None, traffic_mirror_target_id=None, traffic_mirror_target_name=None, updated_at=None):
        if created_at and not isinstance(created_at, str):
            raise TypeError("Expected argument 'created_at' to be a str")
        pulumi.set(__self__, "created_at", created_at)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if instance_type and not isinstance(instance_type, str):
            raise TypeError("Expected argument 'instance_type' to be a str")
        pulumi.set(__self__, "instance_type", instance_type)
        if project_name and not isinstance(project_name, str):
            raise TypeError("Expected argument 'project_name' to be a str")
        pulumi.set(__self__, "project_name", project_name)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, list):
            raise TypeError("Expected argument 'tags' to be a list")
        pulumi.set(__self__, "tags", tags)
        if traffic_mirror_target_id and not isinstance(traffic_mirror_target_id, str):
            raise TypeError("Expected argument 'traffic_mirror_target_id' to be a str")
        pulumi.set(__self__, "traffic_mirror_target_id", traffic_mirror_target_id)
        if traffic_mirror_target_name and not isinstance(traffic_mirror_target_name, str):
            raise TypeError("Expected argument 'traffic_mirror_target_name' to be a str")
        pulumi.set(__self__, "traffic_mirror_target_name", traffic_mirror_target_name)
        if updated_at and not isinstance(updated_at, str):
            raise TypeError("Expected argument 'updated_at' to be a str")
        pulumi.set(__self__, "updated_at", updated_at)

    @property
    @pulumi.getter(name="createdAt")
    def created_at(self) -> builtins.str:
        """
        镜像会话的创建时间。
        """
        return pulumi.get(self, "created_at")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        监听器的描述。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：英文逗号（,）、点（.）、下划线（_）、空格（ ）、等号（=）、中划线（-）、中文逗号（，）、中文句号（。）。长度限制为0 ～ 255个字符。不填则默认值为空字符串。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        镜像目的的资源ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> builtins.str:
        """
        镜像目的的资源类型。NetworkInterface：弹性网卡。ClbInstance：传统型负载均衡。
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> builtins.str:
        """
        镜像目的所属项目的名称。不填默认加入default项目。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter
    def status(self) -> builtins.str:
        """
        镜像目的状态。Available：可用。Creating：创建中。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Sequence['outputs.GetTrafficMirrorTargetTagResult']:
        """
        镜像目的的标签信息。
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="trafficMirrorTargetId")
    def traffic_mirror_target_id(self) -> builtins.str:
        """
        镜像目的的ID。
        """
        return pulumi.get(self, "traffic_mirror_target_id")

    @property
    @pulumi.getter(name="trafficMirrorTargetName")
    def traffic_mirror_target_name(self) -> builtins.str:
        """
        监听器的名称。必须以字母、数字或中文开头，可包含字母、数字、中文及以下特殊字符：点号（.）、下划线_）和中划线（-）。长度限制在1～128字符之间。不填则默认将“协议-端口”作为监听器名称。
        """
        return pulumi.get(self, "traffic_mirror_target_name")

    @property
    @pulumi.getter(name="updatedAt")
    def updated_at(self) -> builtins.str:
        """
        镜像会话的更新时间。
        """
        return pulumi.get(self, "updated_at")


class AwaitableGetTrafficMirrorTargetResult(GetTrafficMirrorTargetResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetTrafficMirrorTargetResult(
            created_at=self.created_at,
            description=self.description,
            id=self.id,
            instance_id=self.instance_id,
            instance_type=self.instance_type,
            project_name=self.project_name,
            status=self.status,
            tags=self.tags,
            traffic_mirror_target_id=self.traffic_mirror_target_id,
            traffic_mirror_target_name=self.traffic_mirror_target_name,
            updated_at=self.updated_at)


def get_traffic_mirror_target(id: Optional[builtins.str] = None,
                              opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetTrafficMirrorTargetResult:
    """
    Data Source schema for Byteplus::VPC::TrafficMirrorTarget


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:vpc/getTrafficMirrorTarget:getTrafficMirrorTarget', __args__, opts=opts, typ=GetTrafficMirrorTargetResult).value

    return AwaitableGetTrafficMirrorTargetResult(
        created_at=pulumi.get(__ret__, 'created_at'),
        description=pulumi.get(__ret__, 'description'),
        id=pulumi.get(__ret__, 'id'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        instance_type=pulumi.get(__ret__, 'instance_type'),
        project_name=pulumi.get(__ret__, 'project_name'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        traffic_mirror_target_id=pulumi.get(__ret__, 'traffic_mirror_target_id'),
        traffic_mirror_target_name=pulumi.get(__ret__, 'traffic_mirror_target_name'),
        updated_at=pulumi.get(__ret__, 'updated_at'))
def get_traffic_mirror_target_output(id: Optional[pulumi.Input[builtins.str]] = None,
                                     opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetTrafficMirrorTargetResult]:
    """
    Data Source schema for Byteplus::VPC::TrafficMirrorTarget


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:vpc/getTrafficMirrorTarget:getTrafficMirrorTarget', __args__, opts=opts, typ=GetTrafficMirrorTargetResult)
    return __ret__.apply(lambda __response__: GetTrafficMirrorTargetResult(
        created_at=pulumi.get(__response__, 'created_at'),
        description=pulumi.get(__response__, 'description'),
        id=pulumi.get(__response__, 'id'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        instance_type=pulumi.get(__response__, 'instance_type'),
        project_name=pulumi.get(__response__, 'project_name'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        traffic_mirror_target_id=pulumi.get(__response__, 'traffic_mirror_target_id'),
        traffic_mirror_target_name=pulumi.get(__response__, 'traffic_mirror_target_name'),
        updated_at=pulumi.get(__response__, 'updated_at')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['AllowListArgs', 'AllowList']

@pulumi.input_type
class AllowListArgs:
    def __init__(__self__, *,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 ignore_instance_status: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        The set of arguments for constructing a AllowList resource.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的备注。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单内的 IP 地址列表
        :param pulumi.Input[builtins.int] associated_instance_num: 白名单下绑定的实例总数。
        :param pulumi.Input[builtins.bool] ignore_instance_status: 是否忽略实例状态校验。取值：true：是。false：否。默认值。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] modify_mode: 修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        :param pulumi.Input[builtins.str] project_name: 所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_allow_lists: 该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        if allow_list_category is not None:
            pulumi.set(__self__, "allow_list_category", allow_list_category)
        if allow_list_desc is not None:
            pulumi.set(__self__, "allow_list_desc", allow_list_desc)
        if allow_list_name is not None:
            pulumi.set(__self__, "allow_list_name", allow_list_name)
        if allow_list_type is not None:
            pulumi.set(__self__, "allow_list_type", allow_list_type)
        if allow_lists is not None:
            pulumi.set(__self__, "allow_lists", allow_lists)
        if associated_instance_num is not None:
            pulumi.set(__self__, "associated_instance_num", associated_instance_num)
        if ignore_instance_status is not None:
            pulumi.set(__self__, "ignore_instance_status", ignore_instance_status)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if modify_mode is not None:
            pulumi.set(__self__, "modify_mode", modify_mode)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if security_group_bind_infos is not None:
            pulumi.set(__self__, "security_group_bind_infos", security_group_bind_infos)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if update_security_group is not None:
            pulumi.set(__self__, "update_security_group", update_security_group)
        if user_allow_lists is not None:
            pulumi.set(__self__, "user_allow_lists", user_allow_lists)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        """
        return pulumi.get(self, "allow_list_category")

    @allow_list_category.setter
    def allow_list_category(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_category", value)

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单的备注。
        """
        return pulumi.get(self, "allow_list_desc")

    @allow_list_desc.setter
    def allow_list_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_desc", value)

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单名称。
        """
        return pulumi.get(self, "allow_list_name")

    @allow_list_name.setter
    def allow_list_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_name", value)

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        """
        return pulumi.get(self, "allow_list_type")

    @allow_list_type.setter
    def allow_list_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_type", value)

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        白名单内的 IP 地址列表
        """
        return pulumi.get(self, "allow_lists")

    @allow_lists.setter
    def allow_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allow_lists", value)

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        白名单下绑定的实例总数。
        """
        return pulumi.get(self, "associated_instance_num")

    @associated_instance_num.setter
    def associated_instance_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "associated_instance_num", value)

    @property
    @pulumi.getter(name="ignoreInstanceStatus")
    def ignore_instance_status(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否忽略实例状态校验。取值：true：是。false：否。默认值。
        """
        return pulumi.get(self, "ignore_instance_status")

    @ignore_instance_status.setter
    def ignore_instance_status(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ignore_instance_status", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        """
        return pulumi.get(self, "modify_mode")

    @modify_mode.setter
    def modify_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modify_mode", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]:
        return pulumi.get(self, "security_group_bind_infos")

    @security_group_bind_infos.setter
    def security_group_bind_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]):
        pulumi.set(self, "security_group_bind_infos", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        """
        return pulumi.get(self, "update_security_group")

    @update_security_group.setter
    def update_security_group(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "update_security_group", value)

    @property
    @pulumi.getter(name="userAllowLists")
    def user_allow_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        return pulumi.get(self, "user_allow_lists")

    @user_allow_lists.setter
    def user_allow_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "user_allow_lists", value)


@pulumi.input_type
class _AllowListState:
    def __init__(__self__, *,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_id: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_ip_num: Optional[pulumi.Input[builtins.int]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 associated_instances: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListAssociatedInstanceArgs']]]] = None,
                 ignore_instance_status: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 ip_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None):
        """
        Input properties used for looking up and filtering AllowList resources.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的备注。
        :param pulumi.Input[builtins.str] allow_list_id: 白名单 ID 。
        :param pulumi.Input[builtins.int] allow_list_ip_num: 白名单内的 IP 地址（或地址段）总数。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单内的 IP 地址列表
        :param pulumi.Input[builtins.int] associated_instance_num: 白名单下绑定的实例总数。
        :param pulumi.Input[builtins.bool] ignore_instance_status: 是否忽略实例状态校验。取值：true：是。false：否。默认值。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ip_lists: 白名单包含的 IP 地址和 IP 地址段的列表。在请求参数 WithIpList 取值为 true 时返回，在取值为 false 或不为其传值时返回为 null。
        :param pulumi.Input[builtins.str] modify_mode: 修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        :param pulumi.Input[builtins.str] project_name: 所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_allow_lists: 该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        if allow_list_category is not None:
            pulumi.set(__self__, "allow_list_category", allow_list_category)
        if allow_list_desc is not None:
            pulumi.set(__self__, "allow_list_desc", allow_list_desc)
        if allow_list_id is not None:
            pulumi.set(__self__, "allow_list_id", allow_list_id)
        if allow_list_ip_num is not None:
            pulumi.set(__self__, "allow_list_ip_num", allow_list_ip_num)
        if allow_list_name is not None:
            pulumi.set(__self__, "allow_list_name", allow_list_name)
        if allow_list_type is not None:
            pulumi.set(__self__, "allow_list_type", allow_list_type)
        if allow_lists is not None:
            pulumi.set(__self__, "allow_lists", allow_lists)
        if associated_instance_num is not None:
            pulumi.set(__self__, "associated_instance_num", associated_instance_num)
        if associated_instances is not None:
            pulumi.set(__self__, "associated_instances", associated_instances)
        if ignore_instance_status is not None:
            pulumi.set(__self__, "ignore_instance_status", ignore_instance_status)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if ip_lists is not None:
            pulumi.set(__self__, "ip_lists", ip_lists)
        if modify_mode is not None:
            pulumi.set(__self__, "modify_mode", modify_mode)
        if project_name is not None:
            pulumi.set(__self__, "project_name", project_name)
        if security_group_bind_infos is not None:
            pulumi.set(__self__, "security_group_bind_infos", security_group_bind_infos)
        if security_group_ids is not None:
            pulumi.set(__self__, "security_group_ids", security_group_ids)
        if update_security_group is not None:
            pulumi.set(__self__, "update_security_group", update_security_group)
        if user_allow_lists is not None:
            pulumi.set(__self__, "user_allow_lists", user_allow_lists)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        """
        return pulumi.get(self, "allow_list_category")

    @allow_list_category.setter
    def allow_list_category(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_category", value)

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单的备注。
        """
        return pulumi.get(self, "allow_list_desc")

    @allow_list_desc.setter
    def allow_list_desc(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_desc", value)

    @property
    @pulumi.getter(name="allowListId")
    def allow_list_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单 ID 。
        """
        return pulumi.get(self, "allow_list_id")

    @allow_list_id.setter
    def allow_list_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_id", value)

    @property
    @pulumi.getter(name="allowListIpNum")
    def allow_list_ip_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        白名单内的 IP 地址（或地址段）总数。
        """
        return pulumi.get(self, "allow_list_ip_num")

    @allow_list_ip_num.setter
    def allow_list_ip_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "allow_list_ip_num", value)

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单名称。
        """
        return pulumi.get(self, "allow_list_name")

    @allow_list_name.setter
    def allow_list_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_name", value)

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        """
        return pulumi.get(self, "allow_list_type")

    @allow_list_type.setter
    def allow_list_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "allow_list_type", value)

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        白名单内的 IP 地址列表
        """
        return pulumi.get(self, "allow_lists")

    @allow_lists.setter
    def allow_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "allow_lists", value)

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        白名单下绑定的实例总数。
        """
        return pulumi.get(self, "associated_instance_num")

    @associated_instance_num.setter
    def associated_instance_num(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "associated_instance_num", value)

    @property
    @pulumi.getter(name="associatedInstances")
    def associated_instances(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AllowListAssociatedInstanceArgs']]]]:
        return pulumi.get(self, "associated_instances")

    @associated_instances.setter
    def associated_instances(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListAssociatedInstanceArgs']]]]):
        pulumi.set(self, "associated_instances", value)

    @property
    @pulumi.getter(name="ignoreInstanceStatus")
    def ignore_instance_status(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否忽略实例状态校验。取值：true：是。false：否。默认值。
        """
        return pulumi.get(self, "ignore_instance_status")

    @ignore_instance_status.setter
    def ignore_instance_status(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "ignore_instance_status", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="ipLists")
    def ip_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        白名单包含的 IP 地址和 IP 地址段的列表。在请求参数 WithIpList 取值为 true 时返回，在取值为 false 或不为其传值时返回为 null。
        """
        return pulumi.get(self, "ip_lists")

    @ip_lists.setter
    def ip_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "ip_lists", value)

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        """
        return pulumi.get(self, "modify_mode")

    @modify_mode.setter
    def modify_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "modify_mode", value)

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        """
        return pulumi.get(self, "project_name")

    @project_name.setter
    def project_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "project_name", value)

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]:
        return pulumi.get(self, "security_group_bind_infos")

    @security_group_bind_infos.setter
    def security_group_bind_infos(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['AllowListSecurityGroupBindInfoArgs']]]]):
        pulumi.set(self, "security_group_bind_infos", value)

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        """
        return pulumi.get(self, "security_group_ids")

    @security_group_ids.setter
    def security_group_ids(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "security_group_ids", value)

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        """
        return pulumi.get(self, "update_security_group")

    @update_security_group.setter
    def update_security_group(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "update_security_group", value)

    @property
    @pulumi.getter(name="userAllowLists")
    def user_allow_lists(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        return pulumi.get(self, "user_allow_lists")

    @user_allow_lists.setter
    def user_allow_lists(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "user_allow_lists", value)


@pulumi.type_token("bytepluscc:rdsmysql/allowList:AllowList")
class AllowList(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 ignore_instance_status: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListSecurityGroupBindInfoArgs', 'AllowListSecurityGroupBindInfoArgsDict']]]]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        """
        白名单是数据库连接的安全防控手段，只有白名单内的 IP 地址才能访问数据库。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/allowList:AllowList example "allow_list_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的备注。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单内的 IP 地址列表
        :param pulumi.Input[builtins.int] associated_instance_num: 白名单下绑定的实例总数。
        :param pulumi.Input[builtins.bool] ignore_instance_status: 是否忽略实例状态校验。取值：true：是。false：否。默认值。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.str] modify_mode: 修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        :param pulumi.Input[builtins.str] project_name: 所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_allow_lists: 该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[AllowListArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        白名单是数据库连接的安全防控手段，只有白名单内的 IP 地址才能访问数据库。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/allowList:AllowList example "allow_list_id"
        ```

        :param str resource_name: The name of the resource.
        :param AllowListArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AllowListArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
                 allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
                 allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
                 ignore_instance_status: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 modify_mode: Optional[pulumi.Input[builtins.str]] = None,
                 project_name: Optional[pulumi.Input[builtins.str]] = None,
                 security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListSecurityGroupBindInfoArgs', 'AllowListSecurityGroupBindInfoArgsDict']]]]] = None,
                 security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
                 user_allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AllowListArgs.__new__(AllowListArgs)

            __props__.__dict__["allow_list_category"] = allow_list_category
            __props__.__dict__["allow_list_desc"] = allow_list_desc
            __props__.__dict__["allow_list_name"] = allow_list_name
            __props__.__dict__["allow_list_type"] = allow_list_type
            __props__.__dict__["allow_lists"] = allow_lists
            __props__.__dict__["associated_instance_num"] = associated_instance_num
            __props__.__dict__["ignore_instance_status"] = ignore_instance_status
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["modify_mode"] = modify_mode
            __props__.__dict__["project_name"] = project_name
            __props__.__dict__["security_group_bind_infos"] = security_group_bind_infos
            __props__.__dict__["security_group_ids"] = security_group_ids
            __props__.__dict__["update_security_group"] = update_security_group
            __props__.__dict__["user_allow_lists"] = user_allow_lists
            __props__.__dict__["allow_list_id"] = None
            __props__.__dict__["allow_list_ip_num"] = None
            __props__.__dict__["associated_instances"] = None
            __props__.__dict__["ip_lists"] = None
        super(AllowList, __self__).__init__(
            'bytepluscc:rdsmysql/allowList:AllowList',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allow_list_category: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_desc: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_id: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_ip_num: Optional[pulumi.Input[builtins.int]] = None,
            allow_list_name: Optional[pulumi.Input[builtins.str]] = None,
            allow_list_type: Optional[pulumi.Input[builtins.str]] = None,
            allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            associated_instance_num: Optional[pulumi.Input[builtins.int]] = None,
            associated_instances: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListAssociatedInstanceArgs', 'AllowListAssociatedInstanceArgsDict']]]]] = None,
            ignore_instance_status: Optional[pulumi.Input[builtins.bool]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            ip_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            modify_mode: Optional[pulumi.Input[builtins.str]] = None,
            project_name: Optional[pulumi.Input[builtins.str]] = None,
            security_group_bind_infos: Optional[pulumi.Input[Sequence[pulumi.Input[Union['AllowListSecurityGroupBindInfoArgs', 'AllowListSecurityGroupBindInfoArgsDict']]]]] = None,
            security_group_ids: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            update_security_group: Optional[pulumi.Input[builtins.bool]] = None,
            user_allow_lists: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None) -> 'AllowList':
        """
        Get an existing AllowList resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.str] allow_list_category: 白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        :param pulumi.Input[builtins.str] allow_list_desc: 白名单的备注。
        :param pulumi.Input[builtins.str] allow_list_id: 白名单 ID 。
        :param pulumi.Input[builtins.int] allow_list_ip_num: 白名单内的 IP 地址（或地址段）总数。
        :param pulumi.Input[builtins.str] allow_list_name: 白名单名称。
        :param pulumi.Input[builtins.str] allow_list_type: 白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] allow_lists: 白名单内的 IP 地址列表
        :param pulumi.Input[builtins.int] associated_instance_num: 白名单下绑定的实例总数。
        :param pulumi.Input[builtins.bool] ignore_instance_status: 是否忽略实例状态校验。取值：true：是。false：否。默认值。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] ip_lists: 白名单包含的 IP 地址和 IP 地址段的列表。在请求参数 WithIpList 取值为 true 时返回，在取值为 false 或不为其传值时返回为 null。
        :param pulumi.Input[builtins.str] modify_mode: 修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        :param pulumi.Input[builtins.str] project_name: 所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] security_group_ids: 需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        :param pulumi.Input[builtins.bool] update_security_group: 是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] user_allow_lists: 该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AllowListState.__new__(_AllowListState)

        __props__.__dict__["allow_list_category"] = allow_list_category
        __props__.__dict__["allow_list_desc"] = allow_list_desc
        __props__.__dict__["allow_list_id"] = allow_list_id
        __props__.__dict__["allow_list_ip_num"] = allow_list_ip_num
        __props__.__dict__["allow_list_name"] = allow_list_name
        __props__.__dict__["allow_list_type"] = allow_list_type
        __props__.__dict__["allow_lists"] = allow_lists
        __props__.__dict__["associated_instance_num"] = associated_instance_num
        __props__.__dict__["associated_instances"] = associated_instances
        __props__.__dict__["ignore_instance_status"] = ignore_instance_status
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["ip_lists"] = ip_lists
        __props__.__dict__["modify_mode"] = modify_mode
        __props__.__dict__["project_name"] = project_name
        __props__.__dict__["security_group_bind_infos"] = security_group_bind_infos
        __props__.__dict__["security_group_ids"] = security_group_ids
        __props__.__dict__["update_security_group"] = update_security_group
        __props__.__dict__["user_allow_lists"] = user_allow_lists
        return AllowList(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allowListCategory")
    def allow_list_category(self) -> pulumi.Output[builtins.str]:
        """
        白名单分类。取值：Ordinary：普通白名单。Default：默认白名单。说明该参数作为请求参数时，默认值为 Ordinary。
        """
        return pulumi.get(self, "allow_list_category")

    @property
    @pulumi.getter(name="allowListDesc")
    def allow_list_desc(self) -> pulumi.Output[builtins.str]:
        """
        白名单的备注。
        """
        return pulumi.get(self, "allow_list_desc")

    @property
    @pulumi.getter(name="allowListId")
    def allow_list_id(self) -> pulumi.Output[builtins.str]:
        """
        白名单 ID 。
        """
        return pulumi.get(self, "allow_list_id")

    @property
    @pulumi.getter(name="allowListIpNum")
    def allow_list_ip_num(self) -> pulumi.Output[builtins.int]:
        """
        白名单内的 IP 地址（或地址段）总数。
        """
        return pulumi.get(self, "allow_list_ip_num")

    @property
    @pulumi.getter(name="allowListName")
    def allow_list_name(self) -> pulumi.Output[builtins.str]:
        """
        白名单名称。
        """
        return pulumi.get(self, "allow_list_name")

    @property
    @pulumi.getter(name="allowListType")
    def allow_list_type(self) -> pulumi.Output[builtins.str]:
        """
        白名单内的 IP 地址类型。当前仅支持 IPv4 地址。
        """
        return pulumi.get(self, "allow_list_type")

    @property
    @pulumi.getter(name="allowLists")
    def allow_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        白名单内的 IP 地址列表
        """
        return pulumi.get(self, "allow_lists")

    @property
    @pulumi.getter(name="associatedInstanceNum")
    def associated_instance_num(self) -> pulumi.Output[builtins.int]:
        """
        白名单下绑定的实例总数。
        """
        return pulumi.get(self, "associated_instance_num")

    @property
    @pulumi.getter(name="associatedInstances")
    def associated_instances(self) -> pulumi.Output[Sequence['outputs.AllowListAssociatedInstance']]:
        return pulumi.get(self, "associated_instances")

    @property
    @pulumi.getter(name="ignoreInstanceStatus")
    def ignore_instance_status(self) -> pulumi.Output[builtins.bool]:
        """
        是否忽略实例状态校验。取值：true：是。false：否。默认值。
        """
        return pulumi.get(self, "ignore_instance_status")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="ipLists")
    def ip_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        白名单包含的 IP 地址和 IP 地址段的列表。在请求参数 WithIpList 取值为 true 时返回，在取值为 false 或不为其传值时返回为 null。
        """
        return pulumi.get(self, "ip_lists")

    @property
    @pulumi.getter(name="modifyMode")
    def modify_mode(self) -> pulumi.Output[builtins.str]:
        """
        修改方式，取值范围如下：Cover（默认值）：使用 AllowList 参数中的值覆盖原白名单。Append：在原白名单中增加 AllowList 参数中输入的 IP 地址。Delete：在原白名单中删除 AllowList 参数中输入的 IP 地址。至少需要保留一个 IP 地址。
        """
        return pulumi.get(self, "modify_mode")

    @property
    @pulumi.getter(name="projectName")
    def project_name(self) -> pulumi.Output[builtins.str]:
        """
        所属的项目。说明如您调用接口使用的 AK/SK 属于某个子账号，且该子账号只拥有某个项目的权限，需要传入该请求参数。
        """
        return pulumi.get(self, "project_name")

    @property
    @pulumi.getter(name="securityGroupBindInfos")
    def security_group_bind_infos(self) -> pulumi.Output[Sequence['outputs.AllowListSecurityGroupBindInfo']]:
        return pulumi.get(self, "security_group_bind_infos")

    @property
    @pulumi.getter(name="securityGroupIds")
    def security_group_ids(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        需要关联的安全组 ID 列表。说明您可以调用 DescribeSecurityGroups 接口查询安全组信息，包括安全组 ID。单个白名单单次最多可选择添加 10 个安全组。该字段不能与 SecurityGroupBindInfos 同时使用。
        """
        return pulumi.get(self, "security_group_ids")

    @property
    @pulumi.getter(name="updateSecurityGroup")
    def update_security_group(self) -> pulumi.Output[builtins.bool]:
        """
        是否更新白名单所绑定的安全组。true：更新。false：不更新。默认值。说明该字段仅在白名单已绑定了安全组时生效。可调用 DescribeAllowLists 接口查询白名单是否绑定了安全组。
        """
        return pulumi.get(self, "update_security_group")

    @property
    @pulumi.getter(name="userAllowLists")
    def user_allow_lists(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        该名单中由用户输入的 IP 地址。AllowList 字段中的 IP 为 UserAllowList 和 SecurityGroupBindInfos 包含的 IP 的并集。
        """
        return pulumi.get(self, "user_allow_lists")

